{% extends "../base.html" %}
{% block title %}Arduinozore{% end %}
{% block subtitle %}
<a class="item" href="/">Accueil</a>
<a class="item" href="/settings">Paramètres</a>
{% block submenu%}
<div class="active item">Capteurs</div>
{% end %}
<div class="item">
    <a class="ui green button" href="/sensor/create"><i class="edit outline icon"></i>Créer une configuration</a>
</div>
{% end %}
{% block head %}
{% end %}
{% block body %}
{% end %}
